==> 0.1.tar.gz: laravel-push/src/PushApi.php <==
<?php

namespace Bluesquare\Push;

use Bluesquare\Push\PushTemplate;
use GuzzleHttp\Client;
use Psr\Http\Message\StreamInterface;
use Symfony\Component\HttpFoundation\File\UploadedFile;

class PushApi
{
    /**
     * The API key
     *
     * @var string
     */
    private $api_key;

    public function __construct(string $api_key)
    {
        $this->api_key = $api_key;
    }

    /**
     * @param PushTemplate $template
     * @param $notifiable
     * @return \Psr\Http\Message\StreamInterface
     * @throws PushException
     */
    public function send($template, $notifiable): StreamInterface
    {
        $url = config('push.api_url') ?? 'https://push.bluesquare.io/api/send';

        $client = new Client();

      	if (is_object($notifiable) && isset($notifiable->email)) {
         	$notifiable_recipient = false;
        	$notifiable_email = $notifiable->email;
            $recipients = $template->recipients;

            if (count($recipients) > 0)
                foreach ($recipients as $recipient)
                    if (! empty($recipient['email']))
                        if ($notifiable_email == $recipient['email'])
                            $notifiable_recipient = true;

            if (! $notifiable_recipient)
                $template->recipients[] = [
                    'email' => $notifiable->email
                ];
        }

        $multipart_form = [];

        foreach ($template as $key => $value) {
            if ($key == 'attachments') {
                foreach ($value as $i => $attachment) {
                    $multipart_form[] = [
                        'name' => "{$key}[$i]",
                        'contents' => file_get_contents($attachment['path']),
                        'filename' => $attachment['filename']
                    ];
                }

                continue;
            }

            if (! is_array($value)) {
                $multipart_form[] = [
                    'name' => $key,
                    'contents' => $value
                ];
                continue;
            }

            foreach ($value as $subkey => $subvalue) {
                $multipart_form[] = [
                    'name' => "{$key}[$subkey]" . (is_array($subvalue) ? '[' . key($subvalue) . ']' : '' ),
                    'contents' => (is_array($subvalue) ? reset($subvalue) : $subvalue)
                ];
            }
        }

        try {
      	    return $client->request('post', $url, [
                 'multipart' => $multipart_form,
                 'headers' => [
                    'Authorization' => 'Bearer ' . $this->api_key,
                    'Accept' => 'application/json'
                ]
            ])->getBody();

        } catch(\Exception $e) {
            throw new PushException($e->getMessage());
        }
    }
}

==> 0.4.tar.gz: laravel-push/src/PushApi.php <==
<?php

namespace Bluesquare\Push;

use Bluesquare\Push\PushTemplate;
use GuzzleHttp\Client;
use Illuminate\Support\Arr;
use Psr\Http\Message\StreamInterface;
use Symfony\Component\HttpFoundation\File\UploadedFile;

class PushApi
{
    /**
     * The API key
     *
     * @var string
     */
    private $api_key;

    public function __construct(string $api_key)
    {
        $this->api_key = $api_key;
    }

    /**
     * @param PushTemplate $template
     * @param $notifiable
     * @return \Psr\Http\Message\StreamInterface
     * @throws PushException
     */
    public function send($template, $notifiable): StreamInterface
    {
        $url = config('push.api_url') ?? 'https://push.bluesquare.io/api/send';

        $client = new Client();

      	if (is_object($notifiable) && isset($notifiable->email)) {
         	$notifiable_recipient = false;
        	$notifiable_email = $notifiable->email;
            $recipients = $template->recipients;

            if (count($recipients) > 0)
                foreach ($recipients as $recipient)
                    if (! empty($recipient['email']))
                        if ($notifiable_email == $recipient['email'])
                            $notifiable_recipient = true;

            if (! $notifiable_recipient)
                $template->recipients[] = [
                    'email' => $notifiable->email
                ];
        }

        $multipart_form = [];

        foreach ($template as $key => $value) {
            if ($key == 'attachments') {
                foreach ($value as $i => $attachment) {
                    $multipart_form[] = [
                        'name' => "{$key}[$i]",
                        'contents' => file_get_contents($attachment['path']),
                        'filename' => $attachment['filename']
                    ];
                }

                continue;
            }

            if (! is_array($value)) {
                $multipart_form[] = [
                    'name' => $key,
                    'contents' => $value
                ];
                continue;
            }

            $values = Arr::dot($value);

            foreach ($values as $subkey => $subvalue) {
                $subkey = str_replace('.', '][', $subkey);

                $multipart_form[] = [
                    'name' => "{$key}[$subkey]",
                    'contents' => is_array($subvalue) ? json_encode($subvalue) : $subvalue
                ];
            }
        }
        
        return $client->request('post', $url, [
            'multipart' => $multipart_form,
            'headers' => [
                'Authorization' => 'Bearer ' . $this->api_key,
                'Accept' => 'application/json'
            ]
        ])->getBody();
    }
}
